@@ -4,6 +4,7 @@
 // require_once 'Symfony/Component/Intl/autoload.php'; (alredy required by Intl/Icu)
 
 require_once 'Symfony/Polyfill/Apcu/autoload.php';
+require_once 'Symfony/Polyfill/Ctype/autoload.php';
 require_once 'Symfony/Polyfill/Iconv/autoload.php';
 require_once 'Symfony/Polyfill/Intl/Grapheme/autoload.php';
 require_once 'Symfony/Polyfill/Intl/Icu/autoload.php';
@@ -15,4 +16,5 @@ require_once 'Symfony/Polyfill/Php56/autoload.php';
 require_once 'Symfony/Polyfill/Php70/autoload.php';
 require_once 'Symfony/Polyfill/Php71/autoload.php';
 require_once 'Symfony/Polyfill/Php72/autoload.php';
+require_once 'Symfony/Polyfill/Php73/autoload.php';
 // require_once 'Symfony/Polyfill/Util/autoload.php'; (already required by Php56)
